@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::D;
-$Time::D::VERSION = '0.019';
+$Time::D::VERSION = '0.020';
 # ABSTRACT: Differentiate between two times
 
 use overload (
@@ -37,7 +37,11 @@ method _computed_setter ($d: $key, $new) {
 
     my $ct = Time::C->gmtime($d->comp);
     return $val, sub {
-        $ct->$key -= $val - $_[0];
+        if ($diff{sign} eq '-') {
+            $ct->$key -= $_[0] - $val;
+        } else {
+            $ct->$key -= $val - $_[0];
+        }
         $d->comp = $ct->epoch;
 
         return $d if defined $new;
@@ -238,11 +242,12 @@ Time::D - Differentiate between two times
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
   use Time::D;
+  use Time::C;
   use feature 'say';
 
   # "1 hour ago"
@@ -252,7 +257,7 @@ version 0.019
   say Time::D->new(time)->to_string();
 
   my $d = Time::D->new(time);
-  $d->comp(Time::C->from_string("2000-01-01T00:00:00Z"));
+  $d->comp(Time::C->from_string("2000-01-01T00:00:00Z")->epoch);
 
   # "16 years, 8 months, 4 weeks, 20 hours, 6 minutes, and 3 seconds ago" (at the time of writing)
   say $d->to_string();
@@ -261,7 +266,7 @@ version 0.019
   $d->years = 0;
 
   # "7 months, and 4 weeks ago"
-  $d->months++;
+  $d->months--;
 
   # "2016-02-01T00:00:00Z"
   say Time::C->gmtime($d->comp)->string;
