@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::F;
-$Time::F::VERSION = '0.019';
+$Time::F::VERSION = '0.020';
 # ABSTRACT: Formatting times.
 
 use Carp qw/ croak /;
@@ -126,7 +126,7 @@ Time::F - Formatting times.
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -135,7 +135,7 @@ version 0.019
   use feature 'say';
 
   # "mån 31 okt 2016 14:21:57"
-  say strftime(Time::C->now_utf(), "%c", locale => "sv_SE");
+  say strftime(Time::C->now_utc(), "%c", locale => "sv_SE");
 
 =head1 DESCRIPTION
 
